Learn R Programming

OrgHeatmap (version 0.3.2)

organelle_bodycontour: Organelle Body Contour Data

Description

A dataset containing the contour coordinates for organelle cell outline.

Usage

organelle_bodycontour

Arguments

Format

A data frame with variables for cell contour coordinates